<?php

namespace Drupal\tmgmt_ec_etranslation\Controller;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\tmgmt\JobItemInterface;
use Drupal\tmgmt_ec_etranslation\Plugin\QueueWorker\TranslationQueueWorker;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;

/**
 * Controller for the eTranslation callback endpoints.
 */
class CallbackController implements ContainerInjectionInterface {

  /**
   * The queue factory.
   *
   * @var \Drupal\Core\Queue\QueueFactory
   */
  protected $queue;

  /**
   * The logger channel.
   *
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   */
  protected $logger;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = new static();
    $instance->queue = $container->get('queue');
    $instance->logger = $container->get('logger.channel.tmgmt_ec_etranslation');

    return $instance;
  }

  /**
   * Handles the translation callback from eTranslation.
   */
  public function callback(JobItemInterface $jobItem, Request $request): Response {
    $this->queue->get(TranslationQueueWorker::ID)->createItem([
      $jobItem->id(),
      $request->query->get('external-reference'),
      $request->getContent(),
    ]);

    return new Response('', Response::HTTP_NO_CONTENT);
  }

  /**
   * Handles the success callback from eTranslation.
   */
  public function success(JobItemInterface $jobItem): Response {
    $this->logger->debug('Success callback received for job item @id', ['@id' => $jobItem->id()]);
    $jobItem->addMessage('Success callback received.');

    return new Response('', Response::HTTP_NO_CONTENT);
  }

  /**
   * Handles the error callback from eTranslation.
   */
  public function error(JobItemInterface $jobItem): Response {
    $this->logger->debug('Error callback received for job item @id', ['@id' => $jobItem->id()]);
    $jobItem->addMessage('Error callback received.');

    return new Response('', Response::HTTP_NO_CONTENT);
  }

}
